@@ -1,10 +1,10 @@
 ;;; semantic-util.el --- Utilities for use with semantic token streams
 
-;;; Copyright (C) 1999, 2000 Eric M. Ludlam
+;;; Copyright (C) 1999, 2000, 2001 Eric M. Ludlam
 
 ;; Author: Eric M. Ludlam <zappo@gnu.org>
 ;; Keywords: syntax
-;; X-RCS: $Id: semantic-util.el,v 1.4 2000/10/24 17:53:43 youngs Exp $
+;; X-RCS: $Id: semantic-util.el,v 1.6 2001/02/20 03:23:44 youngs Exp $
 
 ;; This file is not part of GNU Emacs.
 
@@ -39,6 +39,47 @@
 
 ;; Check semantic.el for the other token information extraction functions.
 
+(defmacro semantic-token-token (token)
+  "Retrieve from TOKEN the token identifier.
+ie, the symbol 'variable, 'function, 'type, or other."
+  `(nth 1 ,token))
+
+(defun semantic-token-name (token)
+  "Retrieve the name of TOKEN."
+  (car token))
+
+(defun semantic-token-docstring (token &optional buffer)
+  "Retrieve the documentation of TOKEN.
+Optional argument BUFFER indicates where to get the text from.
+If not provided, then only the POSITION can be provided."
+  (let ((p (nth (- (length token) 2) token)))
+    (if (and p buffer)
+	(save-excursion
+	  (set-buffer buffer)
+	  (semantic-flex-text (car (semantic-flex p (1+ p)))))
+      p)))
+
+(defmacro semantic-token-overlay (token)
+  "Retrieve the OVERLAY part of TOKEN."
+  `(nth (- (length ,token) 1) ,token))
+
+(defmacro semantic-token-extent (token)
+  "Retrieve the extent (START END) of TOKEN."
+  `(let ((over (semantic-token-overlay ,token)))
+     (list (semantic-overlay-start over) (semantic-overlay-end over))))
+
+(defmacro semantic-token-start (token)
+  "Retrieve the start location of TOKEN."
+  `(semantic-overlay-start (semantic-token-overlay ,token)))
+
+(defmacro semantic-token-end (token)
+  "Retrieve the end location of TOKEN."
+  `(semantic-overlay-end (semantic-token-overlay ,token)))
+
+(defmacro semantic-token-buffer (token)
+  "Retrieve the buffer TOKEN resides in."
+  `(semantic-overlay-buffer (semantic-token-overlay ,token)))
+
 (defun semantic-token-type (token)
   "Retrieve the type of TOKEN."
   (if (member (semantic-token-token token)
@@ -852,22 +893,32 @@ file prototypes belong in."
   "Specify that TOKEN should be highlighted.
 Optional FACE specifies the face to use."
   (let ((o (semantic-token-overlay token)))
-    (semantic-overlay-put o 'old-face (semantic-overlay-get o 'face))
-    (semantic-overlay-put o 'face (or face 'highlight))))
+    (semantic-overlay-put o 'old-face
+			  (cons (semantic-overlay-get o 'face)
+				(semantic-overlay-get o 'old-face)))
+    (semantic-overlay-put o 'face (or face 'highlight))
+    ))
 
 (defun semantic-unhighlight-token (token)
   "Unhighlight TOKEN, restoring it's previous face."
   (let ((o (semantic-token-overlay token)))
-    (semantic-overlay-put o 'face (semantic-overlay-get o 'old-face))
-    (semantic-overlay-put o 'old-face nil))
-  (remove-hook 'pre-command-hook
-	       `(lambda () (semantic-unhighlight-token `,token))))
+    (semantic-overlay-put o 'face (car (semantic-overlay-get o 'old-face)))
+    (semantic-overlay-put o 'old-face (cdr (semantic-overlay-get o 'old-face)))
+    ))
 
-(defun semantic-momentary-highlight-token (token)
-  "Highlight TOKEN, removing highlighting when the user hits a key."
-  (semantic-highlight-token token)
+(defun semantic-momentary-unhighlight-token (token)
+  "Unhighlight TOKEN, restoring it's previous face."
+  (semantic-unhighlight-token token)
+  (remove-hook 'pre-command-hook
+	       `(lambda () (semantic-momentary-unhighlight-token ',token))))
+
+(defun semantic-momentary-highlight-token (token &optional face)
+  "Highlight TOKEN, removing highlighting when the user hits a key.
+Optional argument FACE is the face to use for highlighting.
+If FACE is not specified, then `highlight' will be used."
+  (semantic-highlight-token token face)
   (add-hook 'pre-command-hook
-	    `(lambda () (semantic-unhighlight-token ',token))))
+	    `(lambda () (semantic-momentary-unhighlight-token ',token))))
 
 (defun semantic-set-token-face (token face)
   "Specify that TOKEN should use FACE for display."
