@@ -1,11 +1,11 @@
 ;;; semantic.el --- Semantic buffer evaluator.
 
-;;; Copyright (C) 1999, 2000 Eric M. Ludlam
+;;; Copyright (C) 1999, 2000, 2001 Eric M. Ludlam
 
 ;; Author: Eric M. Ludlam <zappo@gnu.org>
-;; Version: 1.3
+;; Version: 1.3.3
 ;; Keywords: syntax
-;; X-RCS: $Id: semantic.el,v 1.59 2000/10/18 03:27:05 zappo Exp $
+;; X-RCS: $Id: semantic.el,v 1.7 2001/02/20 03:23:45 youngs Exp $
 
 ;; This file is not part of GNU Emacs.
 
@@ -231,8 +231,10 @@
       (defalias 'semantic-overlay-put 'set-extent-property)
       (defalias 'semantic-overlay-get 'extent-property)
       (defalias 'semantic-overlay-delete 'delete-extent)
-      (defalias 'semantic-overlays-at 'extents-at)
-      (defalias 'semantic-overlays-in 'extents-in)
+      (defalias 'semantic-overlays-at
+        (lambda (pos) (extent-list nil pos pos)))
+      (defalias 'semantic-overlays-in 
+	(lambda (beg end) (extent-list nil beg end)))
       (defalias 'semantic-overlay-buffer 'extent-buffer)
       (defalias 'semantic-overlay-start 'extent-start-position)
       (defalias 'semantic-overlay-end 'extent-end-position)
@@ -240,6 +242,7 @@
       (defalias 'semantic-overlay-previous-change 'previous-extent-change)
       (defalias 'semantic-overlay-lists
 	(lambda () (list (extent-list))))
+      (defalias 'semantic-overlay-p 'extentp)
       )
   (defalias 'semantic-overlay-live-p 'overlay-buffer)
   (defalias 'semantic-make-overlay 'make-overlay)
@@ -254,6 +257,7 @@
   (defalias 'semantic-overlay-next-change 'next-overlay-change)
   (defalias 'semantic-overlay-previous-change 'previous-overlay-change)
   (defalias 'semantic-overlay-lists 'overlay-lists)
+  (defalias 'semantic-overlay-p 'overlayp)
   )
 
 (defvar semantic-edebug nil
@@ -464,47 +468,6 @@ For language specific hooks, make sure you define this as a local hook.")
 ;;
 ;; See semantic-util for a wider range of utility functions and macros.
 ;;
-(defmacro semantic-token-token (token)
-  "Retrieve from TOKEN the token identifier.
-ie, the symbol 'variable, 'function, 'type, or other."
-  `(nth 1 ,token))
-
-(defun semantic-token-name (token)
-  "Retrieve the name of TOKEN."
-  (car token))
-
-(defun semantic-token-docstring (token &optional buffer)
-  "Retrieve the documentation of TOKEN.
-Optional argument BUFFER indicates where to get the text from.
-If not provided, then only the POSITION can be provided."
-  (let ((p (nth (- (length token) 2) token)))
-    (if (and p buffer)
-	(save-excursion
-	  (set-buffer buffer)
-	  (semantic-flex-text (car (semantic-flex p (1+ p)))))
-      p)))
-
-(defmacro semantic-token-overlay (token)
-  "Retrieve the OVERLAY part of TOKEN."
-  `(nth (- (length ,token) 1) ,token))
-
-(defmacro semantic-token-extent (token)
-  "Retrieve the extent (START END) of TOKEN."
-  `(let ((over (semantic-token-overlay ,token)))
-     (list (semantic-overlay-start over) (semantic-overlay-end over))))
-
-(defmacro semantic-token-start (token)
-  "Retrieve the start location of TOKEN."
-  `(semantic-overlay-start (semantic-token-overlay ,token)))
-
-(defmacro semantic-token-end (token)
-  "Retrieve the end location of TOKEN."
-  `(semantic-overlay-end (semantic-token-overlay ,token)))
-
-(defmacro semantic-token-buffer (token)
-  "Retrieve the buffer TOKEN resides in."
-  `(semantic-overlay-buffer (semantic-token-overlay ,token)))
-
 (defun semantic-token-p (token)
   "Return non-nil if TOKEN is most likely a semantic token."
   (and (listp token)
@@ -649,7 +612,8 @@ the current results on a parse error."
 	     (stream-overlays (car (cdr (cdr nontermsym))))
 	     (tmpet nil)
 	     (token (car (cdr nontermsym)))
-	     (startcdr (nthcdr (- (length token) 2) token)))
+	     (ncdr (- (length token) 2))
+	     (startcdr (if (natnump ncdr) (nthcdr ncdr token))))
 	(if (not nontermsym)
 	    (error "Parse error @ %d" (car (cdr (car stream)))))
 	(semantic-overlay-stack-add stream-overlays)
